@@ -4,13 +4,13 @@
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
+
 DOCUMENTATION = r"""
 ---
 module: users_external_servers_info
-short_description: Information module for Users External Servers
+short_description: Information module for Users External Servers Info
 description:
-- Get all Users External Servers.
-- Get external users authentication servers.
+- This module represents an alias of the module users_external_servers_v1_info
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -26,23 +26,24 @@ options:
       set to "external".
     type: str
 requirements:
-- dnacentersdk >= 2.7.1
+- dnacentersdk >= 2.4.9
 - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for User and Roles GetExternalAuthenticationServersAPI
-  description: Complete reference of the GetExternalAuthenticationServersAPI API.
+- name: Cisco DNA Center documentation for User and Roles GetExternalAuthenticationServersAPIV1
+  description: Complete reference of the GetExternalAuthenticationServersAPIV1 API.
   link: https://developer.cisco.com/docs/dna-center/#!get-external-authentication-servers-api
 notes:
   - SDK Method used are
-    userand_roles.UserandRoles.get_external_authentication_servers_api,
+    user_and_roles.UserandRoles.get_external_authentication_servers_api_v1,
 
   - Paths used are
     get /dna/system/api/v1/users/external-servers,
+  - It should be noted that this module is an alias of users_external_servers_v1_info
 
 """
 
 EXAMPLES = r"""
-- name: Get all Users External Servers
+- name: Get all Users External Servers Info
   cisco.dnac.users_external_servers_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
